@@ -55,6 +55,7 @@ class Settings(TypedDict, total=False):
     pre_bump_hooks: list[str] | None
     post_bump_hooks: list[str] | None
     prerelease_offset: int
+    encoding: str
 
 
 name: str = "cz_conventional_commits"
@@ -66,9 +67,10 @@ config_files: list[str] = [
     ".cz.yaml",
     "cz.yaml",
 ]
+encoding: str = "utf-8"
 
 DEFAULT_SETTINGS: Settings = {
-    "name": "cz_conventional_commits",
+    "name": name,
     "version": None,
     "version_files": [],
     "version_provider": "commitizen",
@@ -93,6 +95,7 @@ DEFAULT_SETTINGS: Settings = {
     "pre_bump_hooks": [],
     "post_bump_hooks": [],
     "prerelease_offset": 0,
+    "encoding": encoding,
 }
 
 MAJOR = "MAJOR"
